==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm2015/lib/igc-geographic-map-series-host-component.js <==
import { IgcSeriesComponent } from "igniteui-webcomponents-charts";
import { getAllPropertyNames, toSpinal, toPoint, fromPoint, fromRect } from "igniteui-webcomponents-core";
/**
 * Base class for hosting chart series in a IgxGeographicMap.Component
*/
export let IgcGeographicMapSeriesHostComponent = /*@__PURE__*/ (() => {
    class IgcGeographicMapSeriesHostComponent extends IgcSeriesComponent {
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcGeographicMapSeriesHostComponent._observedAttributesIgcGeographicMapSeriesHostComponent == null) {
                let names = getAllPropertyNames(IgcGeographicMapSeriesHostComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicMapSeriesHostComponent._observedAttributesIgcGeographicMapSeriesHostComponent = names;
            }
            return IgcGeographicMapSeriesHostComponent._observedAttributesIgcGeographicMapSeriesHostComponent;
        }
        /**
         * Checks if this control is geographic coordinate system
        */
        get isGeographic() {
            return this.i.er;
        }
        /**
         * Gets whether this series supports markers
        */
        get hasMarkers() {
            return this.i.hasMarkers;
        }
        /**
         * The minimum scale at which this series becomes visible.
         * The default value for this property is 1.0, which means the series will always be visible.  At a VisibleFromScale setting of 0.0, the series will never be visible.  At a VisibleFromScale setting of 0.5, the series will be visible as long as the map is zoomed in to at least 200%.
        */
        get visibleFromScale() {
            return this.i.t7;
        }
        set visibleFromScale(v) {
            this.i.t7 = +v;
            this._a("visibleFromScale", this.i.t7);
        }
        /**
         * Gets or sets the coercion methods to use when loading data from data sources.
         * Should be specified before setting any member paths, if being used. Setting it later
         * will not cause data to be reimported into the chart.
        */
        get coercionMethods() {
            return this.i.coercionMethods;
        }
        set coercionMethods(v) {
            this.i.coercionMethods = v;
        }
        /**
         * Called to notify about changes to indexed-based properties, e.g. Brushes, Outlines, MarkerBrushes, MarkerOutlines and refresh series
        
        */
        notifyIndexedPropertiesChanged() {
            this.i.oh();
        }
        getItemValue(item, memberPathName) {
            let iv = this.i.jv(item, memberPathName);
            return (iv);
        }
        /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
        getItem(world) {
            let iv = this.i.js(toPoint(world));
            return (iv);
        }
        getPreviousOrExactIndex(world, skipUnknowns) {
            let iv = this.i.jg(toPoint(world), skipUnknowns);
            return (iv);
        }
        getNextOrExactIndex(world, skipUnknowns) {
            let iv = this.i.je(toPoint(world), skipUnknowns);
            return (iv);
        }
        getSeriesValue(world, useInterpolation, skipUnknowns) {
            let iv = this.i.ia(toPoint(world), useInterpolation, skipUnknowns);
            return (iv);
        }
        getSeriesValuePosition(world, useInterpolation, skipUnknowns) {
            let iv = this.i.tj(toPoint(world), useInterpolation, skipUnknowns);
            return fromPoint(iv);
        }
        /**
         * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinate for which to get a value bounding box for
        */
        getSeriesValueBoundingBox(world) {
            let iv = this.i.tu(toPoint(world));
            return fromRect(iv);
        }
        /**
         * If possible, will return the best available value marker bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinates for which to get a value marker bounding box for
        */
        getSeriesValueMarkerBoundingBox(world) {
            let iv = this.i.tw(toPoint(world));
            return fromRect(iv);
        }
        getSeriesHighValue(world, useInterpolation, skipUnknowns) {
            let iv = this.i.h6(toPoint(world), useInterpolation, skipUnknowns);
            return (iv);
        }
        getSeriesHighValuePosition(world, useInterpolation, skipUnknowns) {
            let iv = this.i.tf(toPoint(world), useInterpolation, skipUnknowns);
            return fromPoint(iv);
        }
        getSeriesLowValue(world, useInterpolation, skipUnknowns) {
            let iv = this.i.h8(toPoint(world), useInterpolation, skipUnknowns);
            return (iv);
        }
        getSeriesLowValuePosition(world, useInterpolation, skipUnknowns) {
            let iv = this.i.th(toPoint(world), useInterpolation, skipUnknowns);
            return fromPoint(iv);
        }
        getSeriesValuePositionFromSeriesPixel(mouse, useInterpolation, skipUnknowns) {
            let iv = this.i.tk(toPoint(mouse), useInterpolation, skipUnknowns);
            return fromPoint(iv);
        }
        getSeriesValueFromSeriesPixel(mouse, useInterpolation, skipUnknowns) {
            let iv = this.i.ib(toPoint(mouse), useInterpolation, skipUnknowns);
            return (iv);
        }
        /**
         * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
        
        */
        getItemSpan() {
            let iv = this.i.h1();
            return (iv);
        }
        /**
         * Renders the series.
        
        * @param animate  * True if the change should be animated.
        */
        renderSeries(animate) {
            this.i.pr(animate);
        }
        /**
         * Called when this series' Style is updated.
        
        */
        styleUpdated() {
            this.i.qa();
        }
    }
    IgcGeographicMapSeriesHostComponent._observedAttributesIgcGeographicMapSeriesHostComponent = null;
    return IgcGeographicMapSeriesHostComponent;
})();

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm2015/lib/igc-geographic-map-series-host-component.js <==
import { IgcSeriesComponent } from "igniteui-webcomponents-charts";
import { getAllPropertyNames, toSpinal, toPoint, fromPoint, fromRect } from "igniteui-webcomponents-core";
/**
 * Base class for hosting chart series in a IgxGeographicMap.Component
*/
export let IgcGeographicMapSeriesHostComponent = /*@__PURE__*/ (() => {
    class IgcGeographicMapSeriesHostComponent extends IgcSeriesComponent {
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcGeographicMapSeriesHostComponent._observedAttributesIgcGeographicMapSeriesHostComponent == null) {
                let names = getAllPropertyNames(IgcGeographicMapSeriesHostComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicMapSeriesHostComponent._observedAttributesIgcGeographicMapSeriesHostComponent = names;
            }
            return IgcGeographicMapSeriesHostComponent._observedAttributesIgcGeographicMapSeriesHostComponent;
        }
        /**
         * Checks if this control is geographic coordinate system
        */
        get isGeographic() {
            return this.i.fc;
        }
        /**
         * Gets whether this series supports markers
        */
        get hasMarkers() {
            return this.i.hasMarkers;
        }
        /**
         * The minimum scale at which this series becomes visible.
         * The default value for this property is 1.0, which means the series will always be visible.  At a VisibleFromScale setting of 0.0, the series will never be visible.  At a VisibleFromScale setting of 0.5, the series will be visible as long as the map is zoomed in to at least 200%.
        */
        get visibleFromScale() {
            return this.i.w4;
        }
        set visibleFromScale(v) {
            this.i.w4 = +v;
            this._a("visibleFromScale", this.i.w4);
        }
        /**
         * Gets or sets the coercion methods to use when loading data from data sources.
         * Should be specified before setting any member paths, if being used. Setting it later
         * will not cause data to be reimported into the chart.
        */
        get coercionMethods() {
            return this.i.coercionMethods;
        }
        set coercionMethods(v) {
            this.i.coercionMethods = v;
        }
        /**
         * Called to notify about changes to indexed-based properties, e.g. Brushes, Outlines, MarkerBrushes, MarkerOutlines and refresh series
        
        */
        notifyIndexedPropertiesChanged() {
            this.i.qg();
        }
        getItemValue(item, memberPathName) {
            let iv = this.i.kq(item, memberPathName);
            return (iv);
        }
        /**
         * Gets the value of a requested member path from the series.
        
        * @param memberPathName  * The property name of a valid member path for the series
        */
        getMemberPathValue(memberPathName) {
            let iv = this.i.md(memberPathName);
            return (iv);
        }
        /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
        getItem(world) {
            let iv = this.i.kn(toPoint(world));
            return (iv);
        }
        getPreviousOrExactIndex(world, skipUnknowns) {
            let iv = this.i.ka(toPoint(world), skipUnknowns);
            return (iv);
        }
        getNextOrExactIndex(world, skipUnknowns) {
            let iv = this.i.j8(toPoint(world), skipUnknowns);
            return (iv);
        }
        getSeriesValue(world, useInterpolation, skipUnknowns) {
            let iv = this.i.i5(toPoint(world), useInterpolation, skipUnknowns);
            return (iv);
        }
        getSeriesValuePosition(world, useInterpolation, skipUnknowns) {
            let iv = this.i.we(toPoint(world), useInterpolation, skipUnknowns);
            return fromPoint(iv);
        }
        /**
         * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinate for which to get a value bounding box for
        */
        getSeriesValueBoundingBox(world) {
            let iv = this.i.wp(toPoint(world));
            return fromRect(iv);
        }
        /**
         * If possible, will return the best available value marker bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinates for which to get a value marker bounding box for
        */
        getSeriesValueMarkerBoundingBox(world) {
            let iv = this.i.wr(toPoint(world));
            return fromRect(iv);
        }
        getSeriesHighValue(world, useInterpolation, skipUnknowns) {
            let iv = this.i.i1(toPoint(world), useInterpolation, skipUnknowns);
            return (iv);
        }
        getSeriesHighValuePosition(world, useInterpolation, skipUnknowns) {
            let iv = this.i.wa(toPoint(world), useInterpolation, skipUnknowns);
            return fromPoint(iv);
        }
        getSeriesLowValue(world, useInterpolation, skipUnknowns) {
            let iv = this.i.i3(toPoint(world), useInterpolation, skipUnknowns);
            return (iv);
        }
        getSeriesLowValuePosition(world, useInterpolation, skipUnknowns) {
            let iv = this.i.wc(toPoint(world), useInterpolation, skipUnknowns);
            return fromPoint(iv);
        }
        getSeriesValuePositionFromSeriesPixel(mouse, useInterpolation, skipUnknowns) {
            let iv = this.i.wf(toPoint(mouse), useInterpolation, skipUnknowns);
            return fromPoint(iv);
        }
        getSeriesValueFromSeriesPixel(mouse, useInterpolation, skipUnknowns) {
            let iv = this.i.i6(toPoint(mouse), useInterpolation, skipUnknowns);
            return (iv);
        }
        /**
         * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
        
        */
        getItemSpan() {
            let iv = this.i.iw();
            return (iv);
        }
        /**
         * Renders the series.
        
        * @param animate  * True if the change should be animated.
        */
        renderSeries(animate) {
            this.i.rs(animate);
        }
        /**
         * Called when this series' Style is updated.
        
        */
        styleUpdated() {
            this.i.se();
        }
    }
    IgcGeographicMapSeriesHostComponent._observedAttributesIgcGeographicMapSeriesHostComponent = null;
    return IgcGeographicMapSeriesHostComponent;
})();
